hop documentation
===========================

:code:`hop-client` is a pub-sub client library for Multimessenger Astrophysics.

User's Guide
------------

.. toctree::
   :maxdepth: 1

   user/installation
   user/quickstart
   user/stream
   user/auth
   user/models
   user/robust_publication
   user/large_messages
   user/commands

API Reference
-------------

.. toctree::
   :maxdepth: 2

   api/api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
